the Aaware development library.

## Cross Compile armhf

```sh
./build.sh -aarmhf
```

## Cross Compile arm64

```sh
./build.sh -aarm64
```

## Compile x86_64 (macos)

```sh
./build.sh -aosx-x86_64
```

## Compile x86_64 (linux)

```sh
./build.sh -ax86_64
```

## Compile All Targets

```sh
./build_all.sh
```
